@@ -7,13 +7,13 @@ exceptions	98 	:g  lists	;: 	<g  module-export!	=< 
 fxcopy-bit	Gg  
 fxbit-set?	Hg  fxfirst-bit-set	Ig  fxlength	Jg  fxbit-count	Kg  fxif	Lg  fxxor	Mg  fxior	Ng  fxand	Og  fxnot	Pg  	fx*/carry	Qg  	fx-/carry	Rg  	fx+/carry	Sg  fxmod0	Tg  fxdiv0	Ug  fxdiv0-and-mod0	Vg  fxmod	Wg  fxdiv	Xg  
 fxdiv-and-mod	Yg  fx-	Zg  fx*	[g  fx+	\g  fxmin	]g  fxmax	^g  fxeven?	_g  fxodd?	`g  fxnegative?	ag  fxpositive?	bg  fxzero?	cg  fx<=?	dg  fx>=?	eg  fx<?	fg  fx>?	gg  fx=?	hg  greatest-fixnum	ig  least-fixnum	jg  fixnum-width	kg  fixnum?	l?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\]^_`abcdefghijk -	mg  module-re-export!	nm 	om 	pg  module-replace!	qp 	rp 	sg  % inline-fixnum?-procedure	tg  make-syntax-transformer	ut 	vt 	wg  inline-fixnum?	xg  macro	yg  $sc-dispatch	zy 	{y 	|g  _	}g  any	~|} 	g  
-syntax-object g  syntax-parameterize g  m-RVyoR5T5rzptnpGhVL1M5q-1576 g  top   g  ribcage g  t-1575     f  l-RVyoR5T5rzptnpGhVL1M5q-1581       g  x   f  l-RVyoR5T5rzptnpGhVL1M5q-1578     g  shift g  	proc-name g  args       f  l-cRgq$YjQdFaodVzucSvqda-121827 f  l-cRgq$YjQdFaodVzucSvqda-121828     g  name g  formals g  body     f  l-cRgq$YjQdFaodVzucSvqda-121818 f  l-cRgq$YjQdFaodVzucSvqda-121819 f  l-cRgq$YjQdFaodVzucSvqda-121820     g  make-procedure-name g  prefix     f  l-cRgq$YjQdFaodVzucSvqda-121806 f  l-cRgq$YjQdFaodVzucSvqda-121804       f  l-cRgq$YjQdFaodVzucSvqda-121803      
+syntax-object g  syntax-parameterize g  m-BmJitZItadDZRs9ZpFBz2E-1626 g  top   g  ribcage g  t-1625     f  l-BmJitZItadDZRs9ZpFBz2E-1631       g  x   f  l-BmJitZItadDZRs9ZpFBz2E-1628     g  shift g  	proc-name g  args       f  l-MnhTPbxUSdgWSptI68WCwU-121822 f  l-MnhTPbxUSdgWSptI68WCwU-121823     g  name g  formals g  body     f  l-MnhTPbxUSdgWSptI68WCwU-121813 f  l-MnhTPbxUSdgWSptI68WCwU-121814 f  l-MnhTPbxUSdgWSptI68WCwU-121815     g  make-procedure-name g  prefix     f  l-MnhTPbxUSdgWSptI68WCwU-121801 f  l-MnhTPbxUSdgWSptI68WCwU-121799       f  l-MnhTPbxUSdgWSptI68WCwU-121798      
  g  hygiene       g  private   w  g  identifier-syntax   s        g  lambda   g  obj     g  not   g  =   
     	  "              g  each-any |Ҍ g  syntax-violation     f  Wrong number of arguments f  -source expression failed to match any pattern g  identifier?       s  g  
-assert-fixnum }Ҍ g  or g  dummy g  arg   g  m-RVyoR5T5rzptnpGhVL1M5q-1587     f  l-RVyoR5T5rzptnpGhVL1M5q-1592 f  l-RVyoR5T5rzptnpGhVL1M5q-1593       f  l-RVyoR5T5rzptnpGhVL1M5q-1589         g  and   g  map     w  g  raise   g  make-assertion-violation         g  for-all g  assert-fixnums g  define-fxop*}}} g  defineg  op g  m-RVyoR5T5rzptnpGhVL1M5q-1597  f  l-RVyoR5T5rzptnpGhVL1M5q-1602	f  l-RVyoR5T5rzptnpGhVL1M5q-1603
-f  l-RVyoR5T5rzptnpGhVL1M5q-1604	
+assert-fixnum }Ҍ g  or g  dummy g  arg   g  m-BmJitZItadDZRs9ZpFBz2E-1637     f  l-BmJitZItadDZRs9ZpFBz2E-1642 f  l-BmJitZItadDZRs9ZpFBz2E-1643       f  l-BmJitZItadDZRs9ZpFBz2E-1639         g  and   g  map     w  g  raise   g  make-assertion-violation         g  for-all g  assert-fixnums g  define-fxop*}}} g  defineg  op g  m-BmJitZItadDZRs9ZpFBz2E-1647  f  l-BmJitZItadDZRs9ZpFBz2E-1652	f  l-BmJitZItadDZRs9ZpFBz2E-1653
+f  l-BmJitZItadDZRs9ZpFBz2E-1654	
   
- f  l-RVyoR5T5rzptnpGhVL1M5q-1599 
+ f  l-BmJitZItadDZRs9ZpFBz2E-1649 
    g  case-lambda  g  y       g  apply   !g  >"g  <#g  >=$g  <=%g  zero?&g  	positive?'g  	negative?(g  odd?)g  even?*g  max+g  min,g  )make-implementation-restriction-violation-g  div.g  mod/g  div-and-mod0g  div01g  mod02g  
 div0-and-mod03g  expt4g  
 bitwise-if5g  bitwise-length6g  bitwise-first-bit-set7g  bitwise-copy-bit8g  bitwise-bit-field9g  bitwise-copy-bit-field:g  bitwise-rotate-bit-field;g  bitwise-reverse-bit-fieldC 5       h3    ]4	
@@ -63,7 +63,7 @@ bitwise-if5g  bitwise-length6g  bitwise-first-bit-set7g  bitwise-cop
 	k	 		  g  nameg  fixnum? CkR"   h      ]
 	4 5C       g  obj
 		  g  filenamef  rnrs/arithmetic/fixnums.scm
-	n	 		  g  nameg  % inline-fixnum?-procedure CsR4vwx{~    h   .   ]  C      &       g  t-1575
+	n	 		  g  nameg  % inline-fixnum?-procedure CsR4vwx{~    h   .   ]  C      &       g  t-1625
 		
   		
    Cw      h   _   ]L 6    W       g  a
@@ -72,7 +72,7 @@ bitwise-if5g  bitwise-length6g  bitwise-first-bit-set7g  bitwise-cop
    C    hx      ]4 5$  @4 5$   O @4 5"  	 6$  4	 O ?$  
 @""              g  x
 		q g  tmp		q g  tmp		"	q g  tmp		>	q  g  filenamef  rnrs/arithmetic/fixnums.scm
-	n	 		q   C5wR4vx{  h   0   ]  C      (       g  tmp-1596
+	n	 		q   C5wR4vx{  h   0   ]  C      (       g  tmp-1646
 		
   		
    C   h   >   ]45C   6       g  dummy
